"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const http_1 = __importDefault(require("http"));
const https_1 = __importDefault(require("https"));
class EHttpUtil {
}
EHttpUtil.get = (url, params) => {
    return new Promise((resolve, reject) => {
        if (!url.startsWith('http:') && !url.startsWith('https:')) {
            reject(new Error('Invalid URL'));
            return;
        }
        const queryString = params ? Object.entries(params)
            .map(([key, value]) => `${encodeURIComponent(key)}=${encodeURIComponent(value)}`)
            .join('&') : '';
        const urlWithParams = queryString ? `${url}?${queryString}` : url;
        const httpModule = url.startsWith('https:') ? https_1.default : http_1.default;
        httpModule
            .get(urlWithParams, (res) => {
            let data = [];
            res.on('data', (chunk) => {
                data.push(chunk);
            });
            res.on('end', () => {
                let responseData = Buffer.concat(data);
                resolve(responseData);
            });
        })
            .on('error', (err) => {
            reject(err);
        });
    });
};
EHttpUtil.post = (url, postData) => {
    return new Promise((resolve, reject) => {
        if (!url.startsWith('http:') && !url.startsWith('https:')) {
            reject(new Error('Invalid URL'));
            return;
        }
        const httpModule = url.startsWith('https:') ? https_1.default : http_1.default;
        const options = {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
        };
        const req = httpModule.request(url, options, (res) => {
            let data = [];
            res.on('data', (chunk) => {
                data.push(chunk);
            });
            res.on('end', () => {
                let responseData = Buffer.concat(data);
                resolve(responseData);
            });
        });
        req.on('error', (err) => {
            reject(err);
        });
        req.write(JSON.stringify(postData));
        req.end();
    });
};
exports.default = EHttpUtil;
